#ifndef NT2_INCLUDE_FUNCTIONS_INDEG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_INDEG_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/indeg.hpp>

#endif
